@@ -3,4 +3,9 @@ package TestApp::View::Xslate::Appconfig;
 use strict;
 use base 'Catalyst::View::Xslate';
 
-1;
\ No newline at end of file
+__PACKAGE__->config(
+  verbose => 0,
+  type => 'text',
+);
+
+1;
